Module dav_server::actix
source · Available on crate feature
actix-compat only.Expand description
Adapters to use the standard http types with Actix.
Using the adapters in this crate, it’s easy to build a webdav handler for actix:
use dav_server::{DavHandler, actix::DavRequest, actix::DavResponse};
use actix_web::web;
pub async fn dav_handler(req: DavRequest, davhandler: web::Data<DavHandler>) -> DavResponse {
davhandler.handle(req.request).await.into()
}Structs
- Body type for
DavRequest. - http::Request compatibility.
http::Responsecompatibility.