Module dav_server::warp
source · Available on crate feature
warp-compat only.Expand description
Adapter for the warp HTTP server framework.
The filters in this module will always succeed and never return an error. For example, if a file is not found, the filter will return a 404 reply, and not an internal rejection.
Functions
- Creates a Filter that serves files and directories at the base path joined with the remainder of the request path, like
warp::filters::fs::dir. - Creates a Filter that serves a single file, ignoring the request path, like
warp::filters::fs::file. - Reply-filter that runs a DavHandler.